# 'Polemarch' documentation

# API

Polemarch provides REST API for all it’s functionality accessible via web GUI, because our GUI also uses this API to work. Below there is an information about every entity we have in Polemarch and methods applicable to it.

This is an example of api schema, but you can find actual schema on Polemarch host at `/api/v2/openapi/`.

`GET` `/group/`

  Return all groups.

  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/`

  Create a new group.

  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/`

  Return a group instance.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/group/{pk}/`

  Update a group.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/group/{pk}/`

  Update one or more fields on an existing group.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/group/{pk}/`

  Remove an existing group.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/copy/`

  Copy instance with deps.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/group/`

  Return all groups.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/group/`

  Create a new group.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/group/{group_id}/`

  Return a group instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/group/{pk}/group/{group_id}/`

  Update a group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/group/{pk}/group/{group_id}/`

  Update one or more fields on an existing group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/group/{pk}/group/{group_id}/`

  Remove an existing group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/group/{group_id}/copy/`

  Copy instance with deps.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/group/{group_id}/set_owner/`

  Change instance owner.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/group/{group_id}/variables/`

  Return all variables of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/group/{group_id}/variables/`

  Create a new variable of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/group/{group_id}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/group/{pk}/group/{group_id}/variables/{variables_id}/`

  Update variable value.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/group/{pk}/group/{group_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/group/{pk}/group/{group_id}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/host/`

  Return all hosts.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. type (string) – Instance type. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/host/`

  Create a new host.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/host/{host_id}/`

  Return a host instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/group/{pk}/host/{host_id}/`

  Update a host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/group/{pk}/host/{host_id}/`

  Update one or more fields on an existing host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/group/{pk}/host/{host_id}/`

  Remove an existing host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/host/{host_id}/copy/`

  Copy instance with deps.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/host/{host_id}/set_owner/`

  Change instance owner.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/host/{host_id}/variables/`

  Return all variables of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/host/{host_id}/variables/`

  Create a new variable of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/host/{host_id}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/group/{pk}/host/{host_id}/variables/{variables_id}/`

  Update variable value.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/group/{pk}/host/{host_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/group/{pk}/host/{host_id}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/set_owner/`

  Change instance owner.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/variables/`

  Return all variables of instance.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/group/{pk}/variables/`

  Create a new variable of instance.

  Parameters: | pk (integer) – A unique integer value identifying this group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/group/{pk}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/group/{pk}/variables/{variables_id}/`

  Update variable value.

  Parameters: | pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/group/{pk}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/group/{pk}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | pk (integer) – A unique integer value identifying this group. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/history/`

  Return all history of executions.

  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. mode (string) – Module or playbook name. kind (string) – Kind of execution. status (string) – Status of execution. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. name (string) – A name string value (or comma separated list) of instance. older (string) – Older then this time newer (string) – Newer then this time ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/history/{pk}/`

  Return a execution history instance.

  Parameters: | pk (integer) – A unique integer value identifying this history.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/history/{pk}/`

  Remove an existing history record.

  Parameters: | pk (integer) – A unique integer value identifying this history.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/history/{pk}/cancel/`

  Cencel working task.

  Parameters: | pk (integer) – A unique integer value identifying this history.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/history/{pk}/clear/`

  Clear history output.

  Parameters: | pk (integer) – A unique integer value identifying this history.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/history/{pk}/facts/`

  Get compilated history facts (only for execution ‘module’ with module ‘setup’).

  Parameters: | pk (integer) – A unique integer value identifying this history.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/hook/`

  Return all hooks.

  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. type (string) – Instance type. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/hook/`

  Create a new hook.

  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/hook/{pk}/`

  Return a hook instance.

  Parameters: | pk (integer) – A unique integer value identifying this hook.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/hook/{pk}/`

  Update a hook.

  Parameters: | pk (integer) – A unique integer value identifying this hook.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/hook/{pk}/`

  Update one or more fields on an existing hook.

  Parameters: | pk (integer) – A unique integer value identifying this hook.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/hook/{pk}/`

  Remove an existing hook.

  Parameters: | pk (integer) – A unique integer value identifying this hook.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/host/`

  Return all hosts.

  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. type (string) – Instance type. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/host/`

  Create a new host.

  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/host/{pk}/`

  Return a host instance.

  Parameters: | pk (integer) – A unique integer value identifying this host.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/host/{pk}/`

  Update a host.

  Parameters: | pk (integer) – A unique integer value identifying this host.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/host/{pk}/`

  Update one or more fields on an existing host.

  Parameters: | pk (integer) – A unique integer value identifying this host.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/host/{pk}/`

  Remove an existing host.

  Parameters: | pk (integer) – A unique integer value identifying this host.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/host/{pk}/copy/`

  Copy instance with deps.

  Parameters: | pk (integer) – A unique integer value identifying this host.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/host/{pk}/set_owner/`

  Change instance owner.

  Parameters: | pk (integer) – A unique integer value identifying this host.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/host/{pk}/variables/`

  Return all variables of instance.

  Parameters: | pk (integer) – A unique integer value identifying this host.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/host/{pk}/variables/`

  Create a new variable of instance.

  Parameters: | pk (integer) – A unique integer value identifying this host.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/host/{pk}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | pk (integer) – A unique integer value identifying this host. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/host/{pk}/variables/{variables_id}/`

  Update variable value.

  Parameters: | pk (integer) – A unique integer value identifying this host. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/host/{pk}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | pk (integer) – A unique integer value identifying this host. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/host/{pk}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | pk (integer) – A unique integer value identifying this host. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/`

  Return all inventories.

  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/`

  Create a new inventory.

  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/`

  Return a inventory instance.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/inventory/{pk}/`

  Update a inventory.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/inventory/{pk}/`

  Update one or more fields on an existing inventory.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/inventory/{pk}/`

  Remove an existing inventory.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/all_groups/`

  Return all groups.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/all_groups/{all_groups_id}/`

  Return a group instance.

  Parameters: | all_groups_id (string) – pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/all_hosts/`

  Return all hosts.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. type (string) – Instance type. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/all_hosts/{all_hosts_id}/`

  Return a host instance.

  Parameters: | all_hosts_id (string) – pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/copy/`

  Copy instance with deps.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/group/`

  Return all groups.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/group/`

  Create a new group.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/group/{group_id}/`

  Return a group instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/inventory/{pk}/group/{group_id}/`

  Update a group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/inventory/{pk}/group/{group_id}/`

  Update one or more fields on an existing group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/inventory/{pk}/group/{group_id}/`

  Remove an existing group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/group/{group_id}/copy/`

  Copy instance with deps.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/group/{group_id}/set_owner/`

  Change instance owner.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/group/{group_id}/variables/`

  Return all variables of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/group/{group_id}/variables/`

  Create a new variable of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/group/{group_id}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/inventory/{pk}/group/{group_id}/variables/{variables_id}/`

  Update variable value.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/inventory/{pk}/group/{group_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/inventory/{pk}/group/{group_id}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/host/`

  Return all hosts.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. type (string) – Instance type. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/host/`

  Create a new host.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/host/{host_id}/`

  Return a host instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/inventory/{pk}/host/{host_id}/`

  Update a host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/inventory/{pk}/host/{host_id}/`

  Update one or more fields on an existing host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/inventory/{pk}/host/{host_id}/`

  Remove an existing host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/host/{host_id}/copy/`

  Copy instance with deps.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/host/{host_id}/set_owner/`

  Change instance owner.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/host/{host_id}/variables/`

  Return all variables of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/host/{host_id}/variables/`

  Create a new variable of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/host/{host_id}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/inventory/{pk}/host/{host_id}/variables/{variables_id}/`

  Update variable value.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/inventory/{pk}/host/{host_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/inventory/{pk}/host/{host_id}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/set_owner/`

  Change instance owner.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/variables/`

  Return all variables of instance.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/inventory/{pk}/variables/`

  Create a new variable of instance.

  Parameters: | pk (integer) – A unique integer value identifying this inventory.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/inventory/{pk}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/inventory/{pk}/variables/{variables_id}/`

  Update variable value.

  Parameters: | pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/inventory/{pk}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/inventory/{pk}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | pk (integer) – A unique integer value identifying this inventory. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/`

  Return all projects.

  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. status (string) – Project sync status. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. status__not (string) – Project sync status. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/`

  Create a new project.

  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/`

  Return a project instance.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/`

  Update a project.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/`

  Update one or more fields on an existing project.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/`

  Remove an existing project.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/copy/`

  Copy instance with deps.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/execute_module/`

  Execute ansible -m [module] with arguments.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/execute_playbook/`

  Execute ansible-playbook with arguments.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/group/`

  Return all groups.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/group/`

  Create a new group.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/group/{group_id}/`

  Return a group instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/group/{group_id}/`

  Update a group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/group/{group_id}/`

  Update one or more fields on an existing group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/group/{group_id}/`

  Remove an existing group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/group/{group_id}/copy/`

  Copy instance with deps.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/group/{group_id}/set_owner/`

  Change instance owner.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/group/{group_id}/variables/`

  Return all variables of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/group/{group_id}/variables/`

  Create a new variable of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/group/{group_id}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/group/{group_id}/variables/{variables_id}/`

  Update variable value.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/group/{group_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/group/{group_id}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/history/`

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. mode (string) – Module or playbook name. kind (string) – Kind of execution. status (string) – Status of execution. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. name (string) – A name string value (or comma separated list) of instance. older (string) – Older then this time newer (string) – Newer then this time ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/history/{history_id}/`

  Parameters: | history_id (integer) – A unique integer value identifying instance of this history sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/history/{history_id}/`

  Parameters: | history_id (integer) – A unique integer value identifying instance of this history sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/history/{history_id}/cancel/`

  Cencel working task.

  Parameters: | history_id (integer) – A unique integer value identifying instance of this history sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/history/{history_id}/clear/`

  Clear history output.

  Parameters: | history_id (integer) – A unique integer value identifying instance of this history sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/history/{history_id}/facts/`

  Get compilated history facts (only for execution ‘module’ with module ‘setup’).

  Parameters: | history_id (integer) – A unique integer value identifying instance of this history sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/host/`

  Return all hosts.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. type (string) – Instance type. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/host/`

  Create a new host.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/host/{host_id}/`

  Return a host instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/host/{host_id}/`

  Update a host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/host/{host_id}/`

  Update one or more fields on an existing host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/host/{host_id}/`

  Remove an existing host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/host/{host_id}/copy/`

  Copy instance with deps.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/host/{host_id}/set_owner/`

  Change instance owner.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/host/{host_id}/variables/`

  Return all variables of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/host/{host_id}/variables/`

  Create a new variable of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/host/{host_id}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/host/{host_id}/variables/{variables_id}/`

  Update variable value.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/host/{host_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/host/{host_id}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/`

  Return all inventories.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/`

  Create a new inventory.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/`

  Return a inventory instance.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/inventory/{inventory_id}/`

  Update a inventory.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/inventory/{inventory_id}/`

  Update one or more fields on an existing inventory.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/inventory/{inventory_id}/`

  Remove an existing inventory.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/all_groups/`

  Return all groups.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/all_groups/{all_groups_id}/`

  Return a group instance.

  Parameters: | all_groups_id (string) – inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/all_hosts/`

  Return all hosts.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. type (string) – Instance type. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/all_hosts/{all_hosts_id}/`

  Return a host instance.

  Parameters: | all_hosts_id (string) – inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/copy/`

  Copy instance with deps.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/group/`

  Return all groups.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/group/`

  Create a new group.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/`

  Return a group instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/`

  Update a group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/`

  Update one or more fields on an existing group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/`

  Remove an existing group.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/copy/`

  Copy instance with deps.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/set_owner/`

  Change instance owner.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/`

  Return all variables of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/`

  Create a new variable of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Update variable value.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | group_id (integer) – A unique integer value identifying instance of this groups sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/host/`

  Return all hosts.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. type (string) – Instance type. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. variables (string) – List of variables to filter. Comma separeted “key:value” list. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/host/`

  Create a new host.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/`

  Return a host instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/`

  Update a host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/`

  Update one or more fields on an existing host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/`

  Remove an existing host.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/copy/`

  Copy instance with deps.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/set_owner/`

  Change instance owner.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/`

  Return all variables of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/`

  Create a new variable of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Update variable value.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | host_id (integer) – A unique integer value identifying instance of this hosts sublist. inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/set_owner/`

  Change instance owner.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/variables/`

  Return all variables of instance.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/inventory/{inventory_id}/variables/`

  Create a new variable of instance.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/inventory/{inventory_id}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/inventory/{inventory_id}/variables/{variables_id}/`

  Update variable value.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/inventory/{inventory_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/inventory/{inventory_id}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | inventory_id (integer) – A unique integer value identifying instance of this inventories sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/module/`

  Return all available modules of project.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | path (string) – Full path to module. path__not (string) – Full path to module. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/module/{module_id}/`

  Return a module details of project instance.

  Parameters: | module_id (string) – pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/periodic_task/`

  Return all periodic tasks in project.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. mode (string) – Periodic task module or playbook name. kind (string) – Kind of periodic task. type (string) – Instance type. template (number) – A unique integer id of template used in periodic task. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. name (string) – A name string value (or comma separated list) of instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/periodic_task/`

  Create a new periodic task.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/periodic_task/{periodic_task_id}/`

  Return a perodic task instance.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/periodic_task/{periodic_task_id}/`

  Update a periodic task.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/periodic_task/{periodic_task_id}/`

  Update one or more fields on an existing periodic task.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/periodic_task/{periodic_task_id}/`

  Remove an existing periodic task.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/periodic_task/{periodic_task_id}/execute/`

  Ad-hoc execute periodic task.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/periodic_task/{periodic_task_id}/variables/`

  Return all variables of periodic task.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/periodic_task/{periodic_task_id}/variables/`

  Create a new variable of periodic task.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Return a variable of periodic task.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Update variable value.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | periodic_task_id (integer) – A unique integer value identifying instance of this periodic_task sublist. pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/playbook/`

  Return all playbooks of project.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. playbook (string) – Playbook filename. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. playbook__not (string) – Playbook filename. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/playbook/{playbook_id}/`

  Return a playbook of project instance.

  Parameters: | pk (integer) – A unique integer value identifying this project. playbook_id (integer) – A unique integer value identifying instance of this playbook sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/set_owner/`

  Change instance owner.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/sync/`

  Sync project with repository.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/template/`

  Return all execute templates in project.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. kind (string) – A kind of template. inventory (string) – The inventory id or path in project. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/template/`

  Create a new execute template.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/template/{template_id}/`

  Return a execute template instance.

  Parameters: | pk (integer) – A unique integer value identifying this project. template_id (integer) – A unique integer value identifying instance of this template sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/template/{template_id}/`

  Update a execute template.

  Parameters: | pk (integer) – A unique integer value identifying this project. template_id (integer) – A unique integer value identifying instance of this template sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/template/{template_id}/`

  Update one or more fields on an existing execute template.

  Parameters: | pk (integer) – A unique integer value identifying this project. template_id (integer) – A unique integer value identifying instance of this template sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/template/{template_id}/`

  Remove an existing execute template.

  Parameters: | pk (integer) – A unique integer value identifying this project. template_id (integer) – A unique integer value identifying instance of this template sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/template/{template_id}/execute/`

  Execute template with option.

  Parameters: | pk (integer) – A unique integer value identifying this project. template_id (integer) – A unique integer value identifying instance of this template sublist.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/variables/`

  Return all variables of instance.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. key (string) – A key name string value (or comma separated list) of instance. value (string) – A value of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/project/{pk}/variables/`

  Create a new variable of instance.

  Parameters: | pk (integer) – A unique integer value identifying this project.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/project/{pk}/variables/{variables_id}/`

  Return a variable of instance.

  Parameters: | pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/project/{pk}/variables/{variables_id}/`

  Update variable value.

  Parameters: | pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/project/{pk}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Parameters: | pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/project/{pk}/variables/{variables_id}/`

  Remove an existing variable.

  Parameters: | pk (integer) – A unique integer value identifying this project. variables_id (integer) – A unique integer value identifying instance of this variables sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/team/`

  Return all teams.

  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. name (string) – A name string value (or comma separated list) of instance. id__not (string) – A unique integer value (or comma separated list) identifying this instance. name__not (string) – A name string value (or comma separated list) of instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/team/`

  Create a new team.

  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/team/{pk}/`

  Return a team instance.

  Parameters: | pk (string) – A unique value identifying this user group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/team/{pk}/`

  Update a team.

  Parameters: | pk (string) – A unique value identifying this user group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/team/{pk}/`

  Update one or more fields on an existing team.

  Parameters: | pk (string) – A unique value identifying this user group.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/team/{pk}/`

  Remove an existing team.

  Parameters: | pk (string) – A unique value identifying this user group.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/team/{pk}/copy/`

  Copy instance with deps.

  Parameters: | pk (string) – A unique value identifying this user group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/team/{pk}/set_owner/`

  Change instance owner.

  Parameters: | pk (string) – A unique value identifying this user group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/team/{pk}/user/`

  Return all users.

  Parameters: | pk (string) – A unique value identifying this user group.
  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. username (string) – A name string value (or comma separated list) of instance. is_active (string) – Boolean value meaning status of user. first_name (string) – Users first name. last_name (string) – Users last name. email (string) – Users e-mail value. id__not (string) – A unique integer value (or comma separated list) identifying this instance. username__not (string) – A name string value (or comma separated list) of instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/team/{pk}/user/`

  Create a new user.

  Parameters: | pk (string) – A unique value identifying this user group.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/team/{pk}/user/{user_id}/`

  Return a user instance.

  Parameters: | pk (string) – A unique value identifying this user group. user_id (integer) – A unique integer value identifying instance of this users sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/team/{pk}/user/{user_id}/`

  Update a user.

  Parameters: | pk (string) – A unique value identifying this user group. user_id (integer) – A unique integer value identifying instance of this users sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/team/{pk}/user/{user_id}/`

  Update one or more fields on an existing user.

  Parameters: | pk (string) – A unique value identifying this user group. user_id (integer) – A unique integer value identifying instance of this users sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/team/{pk}/user/{user_id}/`

  Remove an existing user.

  Parameters: | pk (string) – A unique value identifying this user group. user_id (integer) – A unique integer value identifying instance of this users sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/team/{pk}/user/{user_id}/change_password/`

  Create a new user.

  Parameters: | pk (string) – A unique value identifying this user group. user_id (integer) – A unique integer value identifying instance of this users sublist.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/team/{pk}/user/{user_id}/copy/`

  Copy instance with deps.

  Parameters: | pk (string) – A unique value identifying this user group. user_id (integer) – A unique integer value identifying instance of this users sublist.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/team/{pk}/user/{user_id}/settings/`

  A settings object, that allows API settings to be accessed as properties. ** For example:**

  > > from rest_framework.settings import api_settings print(api_settings.DEFAULT_RENDERER_CLASSES)

  > Any setting with string import paths will be automatically resolved and return the class, rather than the string literal.

  Parameters: | pk (string) – A unique value identifying this user group. user_id (integer) – A unique integer value identifying instance of this users sublist.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/team/{pk}/user/{user_id}/settings/`

  A settings object, that allows API settings to be accessed as properties. ** For example:**

  > > from rest_framework.settings import api_settings print(api_settings.DEFAULT_RENDERER_CLASSES)

  > Any setting with string import paths will be automatically resolved and return the class, rather than the string literal.

  Parameters: | pk (string) – A unique value identifying this user group. user_id (integer) – A unique integer value identifying instance of this users sublist.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/team/{pk}/user/{user_id}/settings/`

  A settings object, that allows API settings to be accessed as properties. ** For example:**

  > > from rest_framework.settings import api_settings print(api_settings.DEFAULT_RENDERER_CLASSES)

  > Any setting with string import paths will be automatically resolved and return the class, rather than the string literal.

  Parameters: | pk (string) – A unique value identifying this user group. user_id (integer) – A unique integer value identifying instance of this users sublist.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/user/`

  Return all users.

  Query Parameters:
  | id (string) – A unique integer value (or comma separated list) identifying this instance. username (string) – A name string value (or comma separated list) of instance. is_active (string) – Boolean value meaning status of user. first_name (string) – Users first name. last_name (string) – Users last name. email (string) – Users e-mail value. id__not (string) – A unique integer value (or comma separated list) identifying this instance. username__not (string) – A name string value (or comma separated list) of instance. ordering (string) – Which field to use when ordering the results. limit (integer) – Number of results to return per page. offset (integer) – The initial index from which to return the results.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/user/`

  Create a new user.

  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/user/{pk}/`

  Return a user instance.

  Parameters: | pk (integer) – A unique integer value identifying this user.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PUT` `/user/{pk}/`

  Update a user.

  Parameters: | pk (integer) – A unique integer value identifying this user.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`PATCH` `/user/{pk}/`

  Update one or more fields on an existing user.

  Parameters: | pk (integer) – A unique integer value identifying this user.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/user/{pk}/`

  Remove an existing user.

  Parameters: | pk (integer) – A unique integer value identifying this user.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/user/{pk}/change_password/`

  Parameters: | pk (integer) – A unique integer value identifying this user.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/user/{pk}/copy/`

  Copy instance with deps.

  Parameters: | pk (integer) – A unique integer value identifying this user.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`GET` `/user/{pk}/settings/`

  Return user settings.

  Parameters: | pk (integer) – A unique integer value identifying this user.
  Status Codes: | 200 OK – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`POST` `/user/{pk}/settings/`

  Return user settings.

  Parameters: | pk (integer) – A unique integer value identifying this user.
  Status Codes: | 201 Created – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.

`DELETE` `/user/{pk}/settings/`

  Return user settings.

  Parameters: | pk (integer) – A unique integer value identifying this user.
  Status Codes: | 204 No Content – Action accepted. 400 Bad Request – Validation error or some data error. 404 Not Found – Not found error. 403 Forbidden – Permission denied error. 401 Unauthorized – Unauthorized access error.